@@ -1,4 +1,4 @@
-## Copyright (C) 2019 John Donoghue <john.donoghue@ieee.org>
+## Copyright (C) 2019-2021 John Donoghue <john.donoghue@ieee.org>
 ## 
 ## This program is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 ## @end deftypefn
 
 function out = read (dev, numbytes, precision)
-  persistent ARDUINO_I2C_READ = 3;
+  persistent ARDUINO_I2C_READ = 7;
   persistent ARDUINO_SERIAL_READ = 3;
   persistent endian;
   if isempty(endian)
@@ -69,7 +69,7 @@ function out = read (dev, numbytes, precision)
 
   % read request
   if strcmp(dev.interface, "I2C")
-    [tmp, sz] = sendCommand (dev.parent, "i2c", ARDUINO_I2C_READ, [dev.devinfo.address numbytes*datasize]);
+    [tmp, sz] = sendCommand (dev.parent, "i2c", ARDUINO_I2C_READ, [dev.devinfo.bus dev.devinfo.address numbytes*datasize]);
   else
     [tmp, sz] = sendCommand (dev.parent, "serial", ARDUINO_SERIAL_READ, [dev.devinfo.id numbytes*datasize dev.devinfo.timeout*10]);
   endif
@@ -80,7 +80,7 @@ function out = read (dev, numbytes, precision)
 
   if (strcmp (precision,'uint16') || strcmp (precision,'int16'))
     sz = sz/2;
-    if (endian == 'L')
+    if (endian != getEndian(dev.parent))
       out = swapbytes (out); 
     endif
   else
