@@ -1,4 +1,4 @@
-## Copyright (C) 2018-2019 John Donoghue <john.donoghue@ieee.org>
+## Copyright (C) 2018-2025 John Donoghue <john.donoghue@ieee.org>
 ## 
 ## This program is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
@@ -153,7 +153,7 @@ function arduinos = scanForArduinos (varargin)
   endif
 
   # get list of serial ports to try
-  ports = serialportlist ();
+  ports = __arduino_serialportlist__ (debug_flag);
 
   for i = 1:numel (ports)
     try
